@@ -33,6 +33,7 @@ class PermissionMixinForm(BaseMixinForm):
                 self.fields['readable_by'].initial = "owner"
 
     def save(self, *args, **kwargs):
+        r = super(PermissionMixinForm, self).save(*args, **kwargs)
 
         readable_by = self.cleaned_data['readable_by']
         if readable_by == "everybody":
@@ -43,4 +44,4 @@ class PermissionMixinForm(BaseMixinForm):
             # Delete anonymous user perm, if any
             self.instance.remove_perm('read', get_anonymous_user())
 
-        return super(PermissionMixinForm, self).save(*args, **kwargs)
+        return r
\ No newline at end of file
