@@ -5,6 +5,7 @@ from . import base
 from .. import models, forms
 from kii import stream, hook
 from ...tests import test_stream
+from kii.tests.test_stream.models import StreamItemChild1
 
 
 class TestStreamItem(base.StreamTestCase):
@@ -74,3 +75,14 @@ class TestStreamItem(base.StreamTestCase):
 
         hook.model_filters.register(stream.models.StreamItem, "title", uppercase)
         self.assertEqual(m1.filtered_title, "TEST")
+
+    def test_stream_item_detail_redirect_to_clean_url_if_any(self):
+        m1 = StreamItemChild1(title="Test", root=self.streams[0])
+        m1.save()
+        m1.root.assign_perm("read", self.anonymous_user)
+        url = m1.reverse_detail()
+        self.assertEqual(url, "/kii/items/{0}".format(m1.pk))
+
+        response = self.client.get(url)
+
+        self.assertRedirects(response, "/kii/test_stream/streamitemchild1/{0}/".format(m1.pk))
